/*
 * $Id: RunTestsParallel.java,v 1.3 2009/12/28 10:07:23 oboehm Exp $
 *
 * Copyright (c) 2009 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 30.11.2009 by oliver (ob@oasd.de)
 */

package patterntesting.annotation.concurrent;

import java.lang.annotation.*;

/**
 * If you mark JUnit classes with this annotation each test method in the
 * class is run in parallel.
 *
 * @author oliver
 * @since 30.11.2009
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ElementType.TYPE})
public @interface RunTestsParallel {
    
    /**
     * If you want to (temporarily) disable the parallel run of test
     * methods (e.g. because you call only one test method direct) you
     * can use this attribute to disable it.
     * <br/>
     * Another (better) way to disable the parallel runs is via the system
     * property "runTestsParallel". Call the Java VM with
     * <tt>-DrunTestsParallel=false</tt> to disable it.
     * 
     * @return true (default)
     */
    boolean enabled() default true;

}
