/*
 * $Id: Broken.java,v 1.5 2009/12/27 21:02:06 oboehm Exp $
 *
 * Copyright (c) 2009 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 23.11.2009 by oliver (ob@oasd.de)
 */

package patterntesting.runtime.annotation;

import static patterntesting.runtime.NullConstants.*;

import java.lang.annotation.*;

/**
 * If you want to mark JUnit tests which does not work for the moment as
 * "broken" you can use this annotation. The tests will be skipped if you
 * run JUnit. You can also add a date till when you want to fix this "broken"
 * test. If the date is reached then the test will fail if it is not fixed
 * (and the @Broken removed).
 * <br/>
 * You can also use this annotation to mark a method or constructor as
 * "broken". If assertions are enabled an AssertionError will be thrown if
 * you call such a broken method. If not only a error message will be logged.
 *
 * @author oliver
 * @since 23.11.2009
 */
@Documented
@Target({ElementType.METHOD, ElementType.CONSTRUCTOR, ElementType.TYPE})
@Retention(RetentionPolicy.RUNTIME)
public @interface Broken {
    
    /**
     * You can change the default string to give a reason why the test is 
     * marked as "broken".
     * 
     * @return "marked as @Broken" as default
     */
    String value() default "marked as @Broken";

    /**
     * Use this attribute to mark the begin of the broken area, when it
     * was detected that your JUnit test or method does not work as expected.
     * <br/>
     * The format of the date is "dd-MMM-yyyy".
     *
     * @return "" as default
     */
    String since() default NULL_STRING;

    /**
     * Use this attribute till you want the broken JUnit test to be fixed.
     * <br/>
     * The format of the date is "dd-MMM-yyyy".
     *
     * @return "" as default (which means no dead end expected)
     */
    String till() default NULL_STRING;

}
