/**
 * $Id: UnsupportedOperation.java,v 1.9 2009/12/19 22:34:09 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * (c)reated 19.10.2008 by oliver (ob@oasd.de)
 */
package patterntesting.runtime.annotation;

import java.lang.annotation.*;

/**
 * This is similar to the @NotYetImplemented annotation. The difference is
 * only the semantic:
 * "@UnsupportedOperation" means, it is not supported yet and the annotated
 * method will probably also not supported in the future.
 * "@NotYetImplemented" means, that the method is not yet implemented but will
 * be available in the (near) future.
 *
 * @see NotYetImplemented
 * @{link "patterntesting.sample.Fraction how to use it"}
 * @see java.text.MessageFormat
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 19.10.2008
 * @version $Revision: 1.9 $
 */
@Documented
@Target({ElementType.METHOD, ElementType.CONSTRUCTOR})
@Retention(RetentionPolicy.RUNTIME)
public @interface UnsupportedOperation {

    /**
     * You can define the text here which is used for the thrown
     * UnsupportedOperationException. You can add "{0}" if you want to see
     * the method name in the exception e.g.
     * <code>@NotYetImplemented("don''t call {0} today")</code>.
     *
     * @return "{0} is not supported" as default
     */
    String value() default "{0} is not supported";
}

/**
 * $Log: UnsupportedOperation.java,v $
 * Revision 1.9  2009/12/19 22:34:09  oboehm
 * trailing spaces removed
 *
 * Revision 1.8  2009/09/25 14:49:43  oboehm
 * javadocs completed with the help of JAutodoc
 *
 * Revision 1.7  2009/09/18 13:54:51  oboehm
 * javadoc warnings fixed
 *
 * Revision 1.6  2009/04/30 21:32:09  oboehm
 * @NotYetImplemented added
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/annotation/UnsupportedOperation.java,v $
 */
