/*
 * $Id: ProfileStatisticMBean.java,v 1.10 2009/12/19 22:34:09 oboehm Exp $
 *
 * Copyright (c) 2009 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package patterntesting.runtime.monitor;

import javax.management.openmbean.TabularData;

/**
 * The Interface ProfileStatisticMBean.
 */
public interface ProfileStatisticMBean {

    /**
     * Reset.
     */
    public void reset();

    /**
     * Gets the max hits.
     *
     * @return the max hits
     */
    public int getMaxHits();

    /**
     * Gets the max hits label.
     *
     * @return the max hits label
     */
    public String getMaxHitsLabel();

    /**
     * Gets the max hits statistic.
     *
     * @return the max hits statistic
     */
    public String getMaxHitsStatistic();

    /**
     * Gets the max total.
     *
     * @return the max total
     */
    public double getMaxTotal();

    /**
     * Gets the max total label.
     *
     * @return the max total label
     */
    public String getMaxTotalLabel();

    /**
     * Gets the max total statistic.
     *
     * @return the max total statistic
     */
    public String getMaxTotalStatistic();

    /**
     * Gets the max avg.
     *
     * @return the max avg
     */
    public double getMaxAvg();

    /**
     * Gets the max avg label.
     *
     * @return the max avg label
     */
    public String getMaxAvgLabel();

    /**
     * Gets the max avg statistic.
     *
     * @return the max avg statistic
     */
    public String getMaxAvgStatistic();

    /**
     * Gets the max max.
     *
     * @return the max max
     */
    public double getMaxMax();

    /**
     * Gets the max max label.
     *
     * @return the max max label
     */
    public String getMaxMaxLabel();

    /**
     * Gets the max max statistic.
     *
     * @return the max max statistic
     */
    public String getMaxMaxStatistic();

    /**
     * Gets the statistics.
     *
     * @return the statistics
     */
    public TabularData getStatistics();

    /**
     * Log statistic.
     */
    public void logStatistic();

    /**
     * Dump statistic.
     */
    public void dumpStatistic();

}

/**
 * $Log: ProfileStatisticMBean.java,v $
 * Revision 1.10  2009/12/19 22:34:09  oboehm
 * trailing spaces removed
 *
 * Revision 1.9  2009/09/25 14:49:43  oboehm
 * javadocs completed with the help of JAutodoc
 *
 * Revision 1.8  2008/12/27 21:16:05  oboehm
 * getStatistics() added
 *
 * Revision 1.7  2008/12/27 17:31:06  oboehm
 * reset() added to MBean interface
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/monitor/ProfileStatisticMBean.java,v $
 */
